"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalScalewayLb = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ScalewayLb' failed as data isn't a dictionary.`
    );
  }
  return {
    domainName: data.domain_name,
    frontendId: data.frontend_id,
    id: data.id,
    isSsl: data.is_ssl,
    zone: data.zone
  };
};
const unmarshalScalewayLbBackendConfig = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ScalewayLbBackendConfig' failed as data isn't a dictionary.`
    );
  }
  return {
    lbs: marshalling.unmarshalArrayOfObject(data.lbs, unmarshalScalewayLb)
  };
};
const unmarshalScalewayS3BackendConfig = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ScalewayS3BackendConfig' failed as data isn't a dictionary.`
    );
  }
  return {
    bucketName: data.bucket_name,
    bucketRegion: data.bucket_region,
    isWebsite: data.is_website
  };
};
const unmarshalBackendStage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'BackendStage' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    pipelineId: data.pipeline_id,
    projectId: data.project_id,
    scalewayLb: data.scaleway_lb ? unmarshalScalewayLbBackendConfig(data.scaleway_lb) : void 0,
    scalewayS3: data.scaleway_s3 ? unmarshalScalewayS3BackendConfig(data.scaleway_s3) : void 0,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalCacheStage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CacheStage' failed as data isn't a dictionary.`
    );
  }
  return {
    backendStageId: data.backend_stage_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    fallbackTtl: data.fallback_ttl,
    id: data.id,
    pipelineId: data.pipeline_id,
    projectId: data.project_id,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalDNSStage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DNSStage' failed as data isn't a dictionary.`
    );
  }
  return {
    backendStageId: data.backend_stage_id,
    cacheStageId: data.cache_stage_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    fqdns: data.fqdns,
    id: data.id,
    pipelineId: data.pipeline_id,
    projectId: data.project_id,
    tlsStageId: data.tls_stage_id,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalPipelineError = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PipelineError' failed as data isn't a dictionary.`
    );
  }
  return {
    code: data.code,
    message: data.message,
    severity: data.severity,
    stage: data.stage,
    type: data.type
  };
};
const unmarshalPipeline = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Pipeline' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    dnsStageId: data.dns_stage_id,
    errors: marshalling.unmarshalArrayOfObject(data.errors, unmarshalPipelineError),
    id: data.id,
    name: data.name,
    projectId: data.project_id,
    status: data.status,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalTLSSecret = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'TLSSecret' failed as data isn't a dictionary.`
    );
  }
  return {
    region: data.region,
    secretId: data.secret_id
  };
};
const unmarshalTLSStage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'TLSStage' failed as data isn't a dictionary.`
    );
  }
  return {
    backendStageId: data.backend_stage_id,
    cacheStageId: data.cache_stage_id,
    certificateExpiresAt: marshalling.unmarshalDate(data.certificate_expires_at),
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    managedCertificate: data.managed_certificate,
    pipelineId: data.pipeline_id,
    projectId: data.project_id,
    secrets: marshalling.unmarshalArrayOfObject(data.secrets, unmarshalTLSSecret),
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalPurgeRequest = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PurgeRequest' failed as data isn't a dictionary.`
    );
  }
  return {
    all: data.all,
    assets: data.assets,
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    pipelineId: data.pipeline_id,
    status: data.status,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalCheckDomainResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckDomainResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    isValid: data.is_valid
  };
};
const unmarshalCheckLbOriginResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckLbOriginResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    errorType: data.error_type,
    isValid: data.is_valid
  };
};
const unmarshalCheckPEMChainResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CheckPEMChainResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    isValid: data.is_valid
  };
};
const unmarshalListBackendStagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListBackendStagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    stages: marshalling.unmarshalArrayOfObject(data.stages, unmarshalBackendStage),
    totalCount: data.total_count
  };
};
const unmarshalListCacheStagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListCacheStagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    stages: marshalling.unmarshalArrayOfObject(data.stages, unmarshalCacheStage),
    totalCount: data.total_count
  };
};
const unmarshalListDNSStagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListDNSStagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    stages: marshalling.unmarshalArrayOfObject(data.stages, unmarshalDNSStage),
    totalCount: data.total_count
  };
};
const unmarshalListPipelinesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPipelinesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pipelines: marshalling.unmarshalArrayOfObject(data.pipelines, unmarshalPipeline),
    totalCount: data.total_count
  };
};
const unmarshalPlanDetails = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PlanDetails' failed as data isn't a dictionary.`
    );
  }
  return {
    packageGb: data.package_gb,
    pipelineLimit: data.pipeline_limit,
    planName: data.plan_name
  };
};
const unmarshalListPlansResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPlansResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    plans: marshalling.unmarshalArrayOfObject(data.plans, unmarshalPlanDetails),
    totalCount: data.total_count
  };
};
const unmarshalListPurgeRequestsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPurgeRequestsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    purgeRequests: marshalling.unmarshalArrayOfObject(
      data.purge_requests,
      unmarshalPurgeRequest
    ),
    totalCount: data.total_count
  };
};
const unmarshalListTLSStagesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListTLSStagesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    stages: marshalling.unmarshalArrayOfObject(data.stages, unmarshalTLSStage),
    totalCount: data.total_count
  };
};
const unmarshalPlan = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Plan' failed as data isn't a dictionary.`
    );
  }
  return {
    planName: data.plan_name
  };
};
const marshalCheckDomainRequest = (request, defaults) => ({
  cname: request.cname,
  fqdn: request.fqdn,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalScalewayLb = (request, defaults) => ({
  domain_name: request.domainName,
  frontend_id: request.frontendId,
  id: request.id,
  is_ssl: request.isSsl,
  zone: request.zone
});
const marshalCheckLbOriginRequest = (request, defaults) => ({
  lb: request.lb !== void 0 ? marshalScalewayLb(request.lb) : void 0
});
const marshalCheckPEMChainRequestSecretChain = (request, defaults) => ({
  secret_id: request.secretId,
  secret_region: request.secretRegion
});
const marshalCheckPEMChainRequest = (request, defaults) => ({
  fqdn: request.fqdn,
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    {
      param: "secret",
      value: request.secret !== void 0 ? marshalCheckPEMChainRequestSecretChain(request.secret) : void 0
    },
    { param: "raw", value: request.raw }
  ])
});
const marshalScalewayLbBackendConfig = (request, defaults) => ({
  lbs: request.lbs.map((elt) => marshalScalewayLb(elt))
});
const marshalScalewayS3BackendConfig = (request, defaults) => ({
  bucket_name: request.bucketName,
  bucket_region: request.bucketRegion,
  is_website: request.isWebsite
});
const marshalCreateBackendStageRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    {
      param: "scaleway_s3",
      value: request.scalewayS3 !== void 0 ? marshalScalewayS3BackendConfig(request.scalewayS3) : void 0
    },
    {
      param: "scaleway_lb",
      value: request.scalewayLb !== void 0 ? marshalScalewayLbBackendConfig(request.scalewayLb) : void 0
    }
  ])
});
const marshalCreateCacheStageRequest = (request, defaults) => ({
  fallback_ttl: request.fallbackTtl,
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
const marshalCreateDNSStageRequest = (request, defaults) => ({
  fqdns: request.fqdns,
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    { param: "tls_stage_id", value: request.tlsStageId },
    { param: "cache_stage_id", value: request.cacheStageId },
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
const marshalCreatePipelineRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([{ param: "dns_stage_id", value: request.dnsStageId }])
});
const marshalCreatePurgeRequestRequest = (request, defaults) => ({
  pipeline_id: request.pipelineId,
  ...marshalling.resolveOneOf([
    { param: "assets", value: request.assets },
    { param: "all", value: request.all }
  ])
});
const marshalTLSSecret = (request, defaults) => ({
  region: request.region,
  secret_id: request.secretId
});
const marshalCreateTLSStageRequest = (request, defaults) => ({
  managed_certificate: request.managedCertificate,
  project_id: request.projectId ?? defaults.defaultProjectId,
  secrets: request.secrets !== void 0 ? request.secrets.map((elt) => marshalTLSSecret(elt)) : void 0,
  ...marshalling.resolveOneOf([
    { param: "cache_stage_id", value: request.cacheStageId },
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
const marshalSelectPlanRequest = (request, defaults) => ({
  plan_name: request.planName,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalUpdateBackendStageRequest = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    {
      param: "scaleway_s3",
      value: request.scalewayS3 !== void 0 ? marshalScalewayS3BackendConfig(request.scalewayS3) : void 0
    },
    {
      param: "scaleway_lb",
      value: request.scalewayLb !== void 0 ? marshalScalewayLbBackendConfig(request.scalewayLb) : void 0
    }
  ])
});
const marshalUpdateCacheStageRequest = (request, defaults) => ({
  fallback_ttl: request.fallbackTtl,
  ...marshalling.resolveOneOf([
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
const marshalUpdateDNSStageRequest = (request, defaults) => ({
  fqdns: request.fqdns,
  ...marshalling.resolveOneOf([
    { param: "tls_stage_id", value: request.tlsStageId },
    { param: "cache_stage_id", value: request.cacheStageId },
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
const marshalUpdatePipelineRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  ...marshalling.resolveOneOf([{ param: "dns_stage_id", value: request.dnsStageId }])
});
const marshalTLSSecretsConfig = (request, defaults) => ({
  tls_secrets: request.tlsSecrets.map((elt) => marshalTLSSecret(elt))
});
const marshalUpdateTLSStageRequest = (request, defaults) => ({
  managed_certificate: request.managedCertificate,
  tls_secrets_config: request.tlsSecretsConfig !== void 0 ? marshalTLSSecretsConfig(request.tlsSecretsConfig) : void 0,
  ...marshalling.resolveOneOf([
    { param: "cache_stage_id", value: request.cacheStageId },
    { param: "backend_stage_id", value: request.backendStageId }
  ])
});
exports.marshalCheckDomainRequest = marshalCheckDomainRequest;
exports.marshalCheckLbOriginRequest = marshalCheckLbOriginRequest;
exports.marshalCheckPEMChainRequest = marshalCheckPEMChainRequest;
exports.marshalCreateBackendStageRequest = marshalCreateBackendStageRequest;
exports.marshalCreateCacheStageRequest = marshalCreateCacheStageRequest;
exports.marshalCreateDNSStageRequest = marshalCreateDNSStageRequest;
exports.marshalCreatePipelineRequest = marshalCreatePipelineRequest;
exports.marshalCreatePurgeRequestRequest = marshalCreatePurgeRequestRequest;
exports.marshalCreateTLSStageRequest = marshalCreateTLSStageRequest;
exports.marshalSelectPlanRequest = marshalSelectPlanRequest;
exports.marshalUpdateBackendStageRequest = marshalUpdateBackendStageRequest;
exports.marshalUpdateCacheStageRequest = marshalUpdateCacheStageRequest;
exports.marshalUpdateDNSStageRequest = marshalUpdateDNSStageRequest;
exports.marshalUpdatePipelineRequest = marshalUpdatePipelineRequest;
exports.marshalUpdateTLSStageRequest = marshalUpdateTLSStageRequest;
exports.unmarshalBackendStage = unmarshalBackendStage;
exports.unmarshalCacheStage = unmarshalCacheStage;
exports.unmarshalCheckDomainResponse = unmarshalCheckDomainResponse;
exports.unmarshalCheckLbOriginResponse = unmarshalCheckLbOriginResponse;
exports.unmarshalCheckPEMChainResponse = unmarshalCheckPEMChainResponse;
exports.unmarshalDNSStage = unmarshalDNSStage;
exports.unmarshalListBackendStagesResponse = unmarshalListBackendStagesResponse;
exports.unmarshalListCacheStagesResponse = unmarshalListCacheStagesResponse;
exports.unmarshalListDNSStagesResponse = unmarshalListDNSStagesResponse;
exports.unmarshalListPipelinesResponse = unmarshalListPipelinesResponse;
exports.unmarshalListPlansResponse = unmarshalListPlansResponse;
exports.unmarshalListPurgeRequestsResponse = unmarshalListPurgeRequestsResponse;
exports.unmarshalListTLSStagesResponse = unmarshalListTLSStagesResponse;
exports.unmarshalPipeline = unmarshalPipeline;
exports.unmarshalPlan = unmarshalPlan;
exports.unmarshalPurgeRequest = unmarshalPurgeRequest;
exports.unmarshalTLSStage = unmarshalTLSStage;
