import { API as ParentAPI } from '../../../bridge';
import type { Region } from '../../../bridge';
import type { AccessSecretVersionByNameRequest, AccessSecretVersionRequest, AccessSecretVersionResponse, AddSecretOwnerRequest, CreateFolderRequest, CreateSecretRequest, CreateSecretVersionRequest, DeleteFolderRequest, DeleteSecretRequest, DestroySecretVersionRequest, DisableSecretVersionRequest, EnableSecretVersionRequest, Folder, GeneratePasswordRequest, GetSecretByNameRequest, GetSecretRequest, GetSecretVersionByNameRequest, GetSecretVersionRequest, ListFoldersRequest, ListFoldersResponse, ListSecretVersionsByNameRequest, ListSecretVersionsRequest, ListSecretVersionsResponse, ListSecretsRequest, ListSecretsResponse, ListTagsRequest, ListTagsResponse, ProtectSecretRequest, Secret, SecretVersion, UnprotectSecretRequest, UpdateSecretRequest, UpdateSecretVersionRequest } from './types.gen';
/**
 * Secret Manager API.
 *
 * This API allows you to manage your Secret Manager services, for storing,
 * accessing and sharing sensitive data such as passwords, API keys and
 * certificates.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Create a secret. You must specify the `region` to create a secret.
     *
     * @param request - The request {@link CreateSecretRequest}
     * @returns A Promise of Secret
     */
    createSecret: (request: Readonly<CreateSecretRequest>) => Promise<Secret>;
    /**
     * Create folder.
     *
     * @param request - The request {@link CreateFolderRequest}
     * @returns A Promise of Folder
     */
    createFolder: (request: Readonly<CreateFolderRequest>) => Promise<Folder>;
    /**
     * Get metadata using the secret's ID. Retrieve the metadata of a secret
     * specified by the `region` and `secret_id` parameters.
     *
     * @param request - The request {@link GetSecretRequest}
     * @returns A Promise of Secret
     */
    getSecret: (request: Readonly<GetSecretRequest>) => Promise<Secret>;
    /**
     * Get metadata using the secret's name. Retrieve the metadata of a secret
     * specified by the `region` and `secret_name` parameters.
     *
     * GetSecretByName usage is now deprecated.
     *
     * Scaleway recommends that you use the `ListSecrets` request with the `name`
     * filter.
     *
     * @deprecated
     * @param request - The request {@link GetSecretByNameRequest}
     * @returns A Promise of Secret
     */
    getSecretByName: (request: Readonly<GetSecretByNameRequest>) => Promise<Secret>;
    /**
     * Update metadata of a secret. Edit a secret's metadata such as name, tag(s),
     * description and ephemeral policy. The secret to update is specified by the
     * `secret_id` and `region` parameters.
     *
     * @param request - The request {@link UpdateSecretRequest}
     * @returns A Promise of Secret
     */
    updateSecret: (request: Readonly<UpdateSecretRequest>) => Promise<Secret>;
    protected pageOfListSecrets: (request?: Readonly<ListSecretsRequest>) => Promise<ListSecretsResponse>;
    /**
     * List secrets. Retrieve the list of secrets created within an Organization
     * and/or Project. You must specify either the `organization_id` or the
     * `project_id` and the `region`.
     *
     * @param request - The request {@link ListSecretsRequest}
     * @returns A Promise of ListSecretsResponse
     */
    listSecrets: (request?: Readonly<ListSecretsRequest>) => Promise<ListSecretsResponse> & {
        all: () => Promise<Secret[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Secret[], void, void>;
    };
    protected pageOfListFolders: (request?: Readonly<ListFoldersRequest>) => Promise<ListFoldersResponse>;
    /**
     * List folders. Retrieve the list of folders created within a Project.
     *
     * @param request - The request {@link ListFoldersRequest}
     * @returns A Promise of ListFoldersResponse
     */
    listFolders: (request?: Readonly<ListFoldersRequest>) => Promise<ListFoldersResponse> & {
        all: () => Promise<Folder[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Folder[], void, void>;
    };
    /**
     * Delete a secret. Delete a given secret specified by the `region` and
     * `secret_id` parameters.
     *
     * @param request - The request {@link DeleteSecretRequest}
     */
    deleteSecret: (request: Readonly<DeleteSecretRequest>) => Promise<void>;
    /**
     * Delete a given folder specified by the `region` and `folder_id` parameters.
     *
     * @param request - The request {@link DeleteFolderRequest}
     */
    deleteFolder: (request: Readonly<DeleteFolderRequest>) => Promise<void>;
    /**
     * Protect a secret. Protect a given secret specified by the `secret_id`
     * parameter. A protected secret can be read and modified but cannot be
     * deleted.
     *
     * @param request - The request {@link ProtectSecretRequest}
     * @returns A Promise of Secret
     */
    protectSecret: (request: Readonly<ProtectSecretRequest>) => Promise<Secret>;
    /**
     * Unprotect a secret. Unprotect a given secret specified by the `secret_id`
     * parameter. An unprotected secret can be read, modified and deleted.
     *
     * @param request - The request {@link UnprotectSecretRequest}
     * @returns A Promise of Secret
     */
    unprotectSecret: (request: Readonly<UnprotectSecretRequest>) => Promise<Secret>;
    /**
     * Allow a product to use the secret.
     *
     * @param request - The request {@link AddSecretOwnerRequest}
     */
    addSecretOwner: (request: Readonly<AddSecretOwnerRequest>) => Promise<void>;
    /**
     * Create a version. Create a version of a given secret specified by the
     * `region` and `secret_id` parameters.
     *
     * @param request - The request {@link CreateSecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    createSecretVersion: (request: Readonly<CreateSecretVersionRequest>) => Promise<SecretVersion>;
    /**
     * Generate a password in a new version. Generate a password for the given
     * secret specified by the `region` and `secret_id` parameters. This will also
     * create a new version of the secret that will store the password.
     *
     * @param request - The request {@link GeneratePasswordRequest}
     * @returns A Promise of SecretVersion
     */
    generatePassword: (request: Readonly<GeneratePasswordRequest>) => Promise<SecretVersion>;
    /**
     * Get metadata of a secret's version using the secret's ID. Retrieve the
     * metadata of a secret's given version specified by the `region`, `secret_id`
     * and `revision` parameters.
     *
     * @param request - The request {@link GetSecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    getSecretVersion: (request: Readonly<GetSecretVersionRequest>) => Promise<SecretVersion>;
    /**
     * Get metadata of a secret's version using the secret's name. Retrieve the
     * metadata of a secret's given version specified by the `region`,
     * `secret_name`, `revision` and `project_id` parameters.
     *
     * This method is deprecated.
     *
     * Scaleway recommends that you use the `ListSecrets` request with the `name`
     * filter to specify the secret version desired, then use the
     * `GetSecretVersion` request.
     *
     * @deprecated
     * @param request - The request {@link GetSecretVersionByNameRequest}
     * @returns A Promise of SecretVersion
     */
    getSecretVersionByName: (request: Readonly<GetSecretVersionByNameRequest>) => Promise<SecretVersion>;
    /**
     * Update metadata of a version. Edit the metadata of a secret's given
     * version, specified by the `region`, `secret_id` and `revision` parameters.
     *
     * @param request - The request {@link UpdateSecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    updateSecretVersion: (request: Readonly<UpdateSecretVersionRequest>) => Promise<SecretVersion>;
    protected pageOfListSecretVersions: (request: Readonly<ListSecretVersionsRequest>) => Promise<ListSecretVersionsResponse>;
    /**
     * List versions of a secret using the secret's ID. Retrieve the list of a
     * given secret's versions specified by the `secret_id` and `region`
     * parameters.
     *
     * @param request - The request {@link ListSecretVersionsRequest}
     * @returns A Promise of ListSecretVersionsResponse
     */
    listSecretVersions: (request: Readonly<ListSecretVersionsRequest>) => Promise<ListSecretVersionsResponse> & {
        all: () => Promise<SecretVersion[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<SecretVersion[], void, void>;
    };
    protected pageOfListSecretVersionsByName: (request: Readonly<ListSecretVersionsByNameRequest>) => Promise<ListSecretVersionsResponse>;
    /**
     * List versions of a secret using the secret's name. Retrieve the list of a
     * given secret's versions specified by the `secret_name`,`region` and
     * `project_id` parameters.
     *
     * This method is deprecated.
     *
     * Scaleway recommends that you use the `ListSecrets` request with the `name`
     * filter to specify the secret version desired, then use the
     * `ListSecretVersions` request.
     *
     * @deprecated
     * @param request - The request {@link ListSecretVersionsByNameRequest}
     * @returns A Promise of ListSecretVersionsResponse
     */
    listSecretVersionsByName: (request: Readonly<ListSecretVersionsByNameRequest>) => Promise<ListSecretVersionsResponse> & {
        all: () => Promise<SecretVersion[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<SecretVersion[], void, void>;
    };
    /**
     * Enable a version. Make a specific version accessible. You must specify the
     * `region`, `secret_id` and `revision` parameters.
     *
     * @param request - The request {@link EnableSecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    enableSecretVersion: (request: Readonly<EnableSecretVersionRequest>) => Promise<SecretVersion>;
    /**
     * Disable a version. Make a specific version inaccessible. You must specify
     * the `region`, `secret_id` and `revision` parameters.
     *
     * @param request - The request {@link DisableSecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    disableSecretVersion: (request: Readonly<DisableSecretVersionRequest>) => Promise<SecretVersion>;
    /**
     * Access a secret's version using the secret's ID. Access sensitive data in a
     * secret's version specified by the `region`, `secret_id` and `revision`
     * parameters.
     *
     * @param request - The request {@link AccessSecretVersionRequest}
     * @returns A Promise of AccessSecretVersionResponse
     */
    accessSecretVersion: (request: Readonly<AccessSecretVersionRequest>) => Promise<AccessSecretVersionResponse>;
    /**
     * Access a secret's version using the secret's name. Access sensitive data in
     * a secret's version specified by the `region`, `secret_name`, `revision` and
     * `project_id` parameters.
     *
     * This method is deprecated.
     *
     * Scaleway recommends that you use the `ListSecrets` request with the `name`
     * filter to specify the secret version desired, then use the
     * `AccessSecretVersion` request.
     *
     * @deprecated
     * @param request - The request {@link AccessSecretVersionByNameRequest}
     * @returns A Promise of AccessSecretVersionResponse
     */
    accessSecretVersionByName: (request: Readonly<AccessSecretVersionByNameRequest>) => Promise<AccessSecretVersionResponse>;
    /**
     * Delete a version. Delete a secret's version and the sensitive data
     * contained in it. Deleting a version is permanent and cannot be undone.
     *
     * @param request - The request {@link DestroySecretVersionRequest}
     * @returns A Promise of SecretVersion
     */
    destroySecretVersion: (request: Readonly<DestroySecretVersionRequest>) => Promise<SecretVersion>;
    protected pageOfListTags: (request?: Readonly<ListTagsRequest>) => Promise<ListTagsResponse>;
    /**
     * List tags. List all tags associated with secrets within a given Project.
     *
     * @param request - The request {@link ListTagsRequest}
     * @returns A Promise of ListTagsResponse
     */
    listTags: (request?: Readonly<ListTagsRequest>) => Promise<ListTagsResponse> & {
        all: () => Promise<string[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<string[], void, void>;
    };
}
