import { enableConsoleLogger, setLogger } from "./internal/logger/index.js";
import { createAdvancedClient, createClient } from "./scw/client.js";
import { withAdditionalInterceptors, withDefaultPageSize, withHTTPClient, withProfile, withUserAgent, withUserAgentSuffix } from "./scw/client-ini-factory.js";
import { Decimal } from "./scw/custom-types.js";
import * as index from "./scw/errors/standard/index.js";
import { isJSONObject } from "./helpers/json.js";
import { createExponentialBackoffStrategy, tryAtIntervals, waitForResource } from "./internal/async/interval-retrier.js";
import { addAsyncHeaderInterceptor } from "./internal/interceptors/helpers.js";
import { API } from "./scw/api.js";
import { authenticateWithSessionToken } from "./scw/auth.js";
import { marshalBlobToScwFile, marshalDecimal, marshalMoney, marshalScwFile, marshalTimeSeries, unmarshalDecimal, unmarshalMoney, unmarshalScwFile, unmarshalServiceInfo, unmarshalTimeSeries, unmarshalTimeSeriesPoint } from "./scw/custom-marshalling.js";
import { resolveOneOf, unmarshalArrayOfObject, unmarshalDate, unmarshalMapOfObject, urlParams, validatePathParam } from "./helpers/marshalling.js";
import { enrichForPagination } from "./scw/fetch/resource-paginator.js";
import * as index_gen$g from "./api/account/index.gen.js";
import * as index_gen from "./api/applesilicon/index.gen.js";
import * as index_gen$1 from "./api/baremetal/index.gen.js";
import * as index_gen$h from "./api/billing/index.gen.js";
import * as index_gen$i from "./api/block/index.gen.js";
import * as index_gen$j from "./api/cockpit/index.gen.js";
import * as index_gen$k from "./api/container/index.gen.js";
import * as index_gen$l from "./api/dedibox/index.gen.js";
import * as index_gen$2 from "./api/document_db/index.gen.js";
import * as index_gen$m from "./api/domain/index.gen.js";
import * as index_gen$n from "./api/edge_services/index.gen.js";
import * as index_gen$3 from "./api/flexibleip/index.gen.js";
import * as index_gen$o from "./api/function/index.gen.js";
import * as index_gen$4 from "./api/iam/index.gen.js";
import * as index_gen$p from "./api/inference/index.gen.js";
import * as index_gen$q from "./api/instance/index.gen.js";
import * as index_gen$5 from "./api/iot/index.gen.js";
import * as index_gen$6 from "./api/ipam/index.gen.js";
import * as index_gen$7 from "./api/ipfs/index.gen.js";
import * as index_gen$r from "./api/jobs/index.gen.js";
import * as index_gen$s from "./api/k8s/index.gen.js";
import * as index_gen$t from "./api/key_manager/index.gen.js";
import * as index_gen$8 from "./api/lb/index.gen.js";
import * as index_gen$9 from "./api/llm_inference/index.gen.js";
import * as index_gen$u from "./api/marketplace/index.gen.js";
import * as index_gen$a from "./api/mnq/index.gen.js";
import * as index_gen$v from "./api/qaas/index.gen.js";
import * as index_gen$b from "./api/rdb/index.gen.js";
import * as index_gen$w from "./api/redis/index.gen.js";
import * as index_gen$x from "./api/registry/index.gen.js";
import * as index_gen$y from "./api/secret/index.gen.js";
import * as index_gen$c from "./api/serverless_sqldb/index.gen.js";
import * as index_gen$z from "./api/std/index.gen.js";
import * as index_gen$d from "./api/tem/index.gen.js";
import * as index_gen$A from "./api/test/index.gen.js";
import * as index_gen$e from "./api/vpc/index.gen.js";
import * as index_gen$f from "./api/vpcgw/index.gen.js";
import * as index_gen$B from "./api/webhosting/index.gen.js";
export {
  API,
  index_gen$g as Account,
  index_gen as AppleSilicon,
  index_gen as Applesilicon,
  index_gen$1 as BareMetal,
  index_gen$1 as Baremetal,
  index_gen$h as Billing,
  index_gen$i as Block,
  index_gen$j as Cockpit,
  index_gen$k as Container,
  Decimal,
  index_gen$l as Dedibox,
  index_gen$2 as DocumentDB,
  index_gen$2 as DocumentDb,
  index_gen$m as Domain,
  index_gen$n as EdgeServices,
  index as Errors,
  index_gen$3 as FlexibleIP,
  index_gen$3 as Flexibleip,
  index_gen$o as Function,
  index_gen$4 as IAM,
  index_gen$5 as IOT,
  index_gen$6 as IPAM,
  index_gen$7 as IPFS,
  index_gen$4 as Iam,
  index_gen$p as Inference,
  index_gen$q as Instance,
  index_gen$5 as Iot,
  index_gen$6 as Ipam,
  index_gen$7 as Ipfs,
  index_gen$r as Jobs,
  index_gen$s as K8s,
  index_gen$t as KeyManager,
  index_gen$8 as LB,
  index_gen$9 as LLMInference,
  index_gen$8 as Lb,
  index_gen$9 as LlmInference,
  index_gen$a as MNQ,
  index_gen$u as Marketplace,
  index_gen$a as Mnq,
  index_gen$v as Qaas,
  index_gen$b as RDB,
  index_gen$b as Rdb,
  index_gen$w as Redis,
  index_gen$x as Registry,
  index_gen$y as Secret,
  index_gen$c as ServerlessSQLDB,
  index_gen$c as ServerlessSqldb,
  index_gen$z as Std,
  index_gen$d as Tem,
  index_gen$A as Test,
  index_gen$d as TransactionalEmail,
  index_gen$e as VPC,
  index_gen$f as VPCGW,
  index_gen$e as Vpc,
  index_gen$f as Vpcgw,
  index_gen$B as Webhosting,
  addAsyncHeaderInterceptor,
  authenticateWithSessionToken,
  createAdvancedClient,
  createClient,
  createExponentialBackoffStrategy,
  enableConsoleLogger,
  enrichForPagination,
  isJSONObject,
  marshalBlobToScwFile,
  marshalDecimal,
  marshalMoney,
  marshalScwFile,
  marshalTimeSeries,
  resolveOneOf,
  setLogger,
  tryAtIntervals,
  unmarshalArrayOfObject,
  unmarshalDate,
  unmarshalDecimal,
  unmarshalMapOfObject,
  unmarshalMoney,
  unmarshalScwFile,
  unmarshalServiceInfo,
  unmarshalTimeSeries,
  unmarshalTimeSeriesPoint,
  urlParams,
  validatePathParam,
  waitForResource,
  withAdditionalInterceptors,
  withDefaultPageSize,
  withHTTPClient,
  withProfile,
  withUserAgent,
  withUserAgentSuffix
};
